@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,17 +20,16 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.video.transcoder_v1beta1.services.transcoder_service import pagers
 from google.cloud.video.transcoder_v1beta1.types import resources
 from google.cloud.video.transcoder_v1beta1.types import services
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import TranscoderServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TranscoderServiceGrpcAsyncIOTransport
 from .client import TranscoderServiceClient
@@ -59,42 +56,67 @@ class TranscoderServiceAsyncClient:
     parse_job_template_path = staticmethod(
         TranscoderServiceClient.parse_job_template_path
     )
-
     common_billing_account_path = staticmethod(
         TranscoderServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         TranscoderServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(TranscoderServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         TranscoderServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         TranscoderServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         TranscoderServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(TranscoderServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         TranscoderServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(TranscoderServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         TranscoderServiceClient.parse_common_location_path
     )
 
-    from_service_account_file = TranscoderServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranscoderServiceAsyncClient: The constructed client.
+        """
+        return TranscoderServiceClient.from_service_account_info.__func__(TranscoderServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranscoderServiceAsyncClient: The constructed client.
+        """
+        return TranscoderServiceClient.from_service_account_file.__func__(TranscoderServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> TranscoderServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             TranscoderServiceTransport: The transport used by the client instance.
@@ -108,12 +130,12 @@ class TranscoderServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, TranscoderServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the transcoder service client.
+        """Instantiates the transcoder service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -145,7 +167,6 @@ class TranscoderServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = TranscoderServiceClient(
             credentials=credentials,
             transport=transport,
@@ -166,22 +187,23 @@ class TranscoderServiceAsyncClient:
         r"""Creates a job in the specified region.
 
         Args:
-            request (:class:`~.services.CreateJobRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.CreateJobRequest`):
                 The request object. Request message for
                 `TranscoderService.CreateJob`.
             parent (:class:`str`):
                 Required. The parent location to create and process this
                 job. Format: ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job (:class:`~.resources.Job`):
+            job (:class:`google.cloud.video.transcoder_v1beta1.types.Job`):
                 Required. Parameters for creating
                 transcoding job.
+
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -189,7 +211,7 @@ class TranscoderServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Job:
+            google.cloud.video.transcoder_v1beta1.types.Job:
                 Transcoding job resource.
         """
         # Create or coerce a protobuf request object.
@@ -206,7 +228,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if job is not None:
@@ -244,17 +265,17 @@ class TranscoderServiceAsyncClient:
         r"""Lists jobs in the specified region.
 
         Args:
-            request (:class:`~.services.ListJobsRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.ListJobsRequest`):
                 The request object. Request message for
                 `TranscoderService.ListJobs`. The parent location from
                 which to retrieve the collection of jobs.
             parent (:class:`str`):
                 Required. Format:
                 ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -262,8 +283,8 @@ class TranscoderServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListJobsAsyncPager:
-                Response message for ``TranscoderService.ListJobs``.
+            google.cloud.video.transcoder_v1beta1.services.transcoder_service.pagers.ListJobsAsyncPager:
+                Response message for TranscoderService.ListJobs.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -283,7 +304,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -325,16 +345,16 @@ class TranscoderServiceAsyncClient:
         r"""Returns the job data.
 
         Args:
-            request (:class:`~.services.GetJobRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.GetJobRequest`):
                 The request object. Request message for
                 `TranscoderService.GetJob`.
             name (:class:`str`):
                 Required. The name of the job to retrieve. Format:
                 ``projects/{project}/locations/{location}/jobs/{job}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -342,7 +362,7 @@ class TranscoderServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Job:
+            google.cloud.video.transcoder_v1beta1.types.Job:
                 Transcoding job resource.
         """
         # Create or coerce a protobuf request object.
@@ -359,7 +379,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -395,16 +414,16 @@ class TranscoderServiceAsyncClient:
         r"""Deletes a job.
 
         Args:
-            request (:class:`~.services.DeleteJobRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.DeleteJobRequest`):
                 The request object. Request message for
                 `TranscoderService.DeleteJob`.
             name (:class:`str`):
                 Required. The name of the job to delete. Format:
                 ``projects/{project}/locations/{location}/jobs/{job}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -425,7 +444,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -462,19 +480,21 @@ class TranscoderServiceAsyncClient:
         r"""Creates a job template in the specified region.
 
         Args:
-            request (:class:`~.services.CreateJobTemplateRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.CreateJobTemplateRequest`):
                 The request object. Request message for
                 `TranscoderService.CreateJobTemplate`.
             parent (:class:`str`):
                 Required. The parent location to create this job
                 template. Format:
                 ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job_template (:class:`~.resources.JobTemplate`):
+            job_template (:class:`google.cloud.video.transcoder_v1beta1.types.JobTemplate`):
                 Required. Parameters for creating job
                 template.
+
                 This corresponds to the ``job_template`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -486,10 +506,10 @@ class TranscoderServiceAsyncClient:
                 This value should be 4-63 characters, and valid
                 characters must match the regular expression
                 ``[a-zA-Z][a-zA-Z0-9_-]*``.
+
                 This corresponds to the ``job_template_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -497,7 +517,7 @@ class TranscoderServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.JobTemplate:
+            google.cloud.video.transcoder_v1beta1.types.JobTemplate:
                 Transcoding job template resource.
         """
         # Create or coerce a protobuf request object.
@@ -514,7 +534,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if job_template is not None:
@@ -554,17 +573,17 @@ class TranscoderServiceAsyncClient:
         r"""Lists job templates in the specified region.
 
         Args:
-            request (:class:`~.services.ListJobTemplatesRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.ListJobTemplatesRequest`):
                 The request object. Request message for
                 `TranscoderService.ListJobTemplates`.
             parent (:class:`str`):
                 Required. The parent location from which to retrieve the
                 collection of job templates. Format:
                 ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -572,9 +591,8 @@ class TranscoderServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListJobTemplatesAsyncPager:
-                Response message for
-                ``TranscoderService.ListJobTemplates``.
+            google.cloud.video.transcoder_v1beta1.services.transcoder_service.pagers.ListJobTemplatesAsyncPager:
+                Response message for TranscoderService.ListJobTemplates.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -594,7 +612,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -636,17 +653,17 @@ class TranscoderServiceAsyncClient:
         r"""Returns the job template data.
 
         Args:
-            request (:class:`~.services.GetJobTemplateRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.GetJobTemplateRequest`):
                 The request object. Request message for
                 `TranscoderService.GetJobTemplate`.
             name (:class:`str`):
                 Required. The name of the job template to retrieve.
                 Format:
                 ``projects/{project}/locations/{location}/jobTemplates/{job_template}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -654,7 +671,7 @@ class TranscoderServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.JobTemplate:
+            google.cloud.video.transcoder_v1beta1.types.JobTemplate:
                 Transcoding job template resource.
         """
         # Create or coerce a protobuf request object.
@@ -671,7 +688,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -707,16 +723,16 @@ class TranscoderServiceAsyncClient:
         r"""Deletes a job template.
 
         Args:
-            request (:class:`~.services.DeleteJobTemplateRequest`):
+            request (:class:`google.cloud.video.transcoder_v1beta1.types.DeleteJobTemplateRequest`):
                 The request object. Request message for
                 `TranscoderService.DeleteJobTemplate`.
             name (:class:`str`):
                 Required. The name of the job template to delete.
                 ``projects/{project}/locations/{location}/jobTemplates/{job_template}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -737,7 +753,6 @@ class TranscoderServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
